@@ -279,6 +279,7 @@ class Resource:
         DISCOVERY_K8S_IO = "discovery.k8s.io"
         EVENTS_K8S_IO = "events.k8s.io"
         EXPORT_KUBEVIRT_IO = "export.kubevirt.io"
+        FENCE_AGENTS_REMEDIATION_MEDIK8S_IO = "fence-agents-remediation.medik8s.io"
         FORKLIFT_KONVEYOR_IO = "forklift.konveyor.io"
         INSTANCETYPE_KUBEVIRT_IO = "instancetype.kubevirt.io"
         HCO_KUBEVIRT_IO = "hco.kubevirt.io"
@@ -327,6 +328,7 @@ class Resource:
         SECURITY_ISTIO_IO = "security.istio.io"
         SECURITY_OPENSHIFT_IO = "security.openshift.io"
         SELF_NODE_REMEDIATION_MEDIK8S_IO = "self-node-remediation.medik8s.io"
+        SERVING_KSERVE_IO = "serving.kserve.io"
         SNAPSHOT_STORAGE_K8S_IO = "snapshot.storage.k8s.io"
         SNAPSHOT_KUBEVIRT_IO = "snapshot.kubevirt.io"
         SRIOVNETWORK_OPENSHIFT_IO = "sriovnetwork.openshift.io"
@@ -339,6 +341,7 @@ class Resource:
         TEKTON_DEV = "tekton.dev"
         TEMPLATE_KUBEVIRT_IO = "template.kubevirt.io"
         TEMPLATE_OPENSHIFT_IO = "template.openshift.io"
+        TRUSTYAI_OPENDATAHUB_IO = "trustyai.opendatahub.io"
         UPLOAD_CDI_KUBEVIRT_IO = "upload.cdi.kubevirt.io"
         USER_OPENSHIFT_IO = "user.openshift.io"
         V2V_KUBEVIRT_IO = "v2v.kubevirt.io"
